Stan Math Library: stan/math/prim/mat/fun/read_corr_matrix.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

read_corr_matrix.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_READ_CORR_MATRIX_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_READ_CORR_MATRIX_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/prim/mat/fun/read_corr_L.hpp>
6 #include <stan/math/prim/mat/fun/multiply_lower_tri_self_transpose.hpp>
7
8 namespace stan {
9
10 namespace math {
11
12
26 template <typename T>
27 Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic>
28 read_corr_matrix(const Eigen::Array<T, Eigen::Dynamic, 1>& CPCs,
29 const size_t K) {
30 Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic> L
31 = read_corr_L(CPCs, K);
32 using stan::math::multiply_lower_tri_self_transpose;
33 return multiply_lower_tri_self_transpose(L);
34 }
35
54 template <typename T>
55 Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic>
56 read_corr_matrix(const Eigen::Array<T, Eigen::Dynamic, 1>& CPCs,
57 const size_t K,
58 T& log_prob) {
59 Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic> L
60 = read_corr_L(CPCs, K, log_prob);
61 using stan::math::multiply_lower_tri_self_transpose;
62 return multiply_lower_tri_self_transpose(L);
63 }
64
65 }
66
67 }
68
69 #endif
multiply_lower_tri_self_transpose.hpp
stan::math::read_corr_matrix
Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > read_corr_matrix(const Eigen::Array< T, Eigen::Dynamic, 1 > &CPCs, const size_t K)
Return the correlation matrix of the specified dimensionality corresponding to the specified canonica...
Definition: read_corr_matrix.hpp:28
stan
Definition: log_sum_exp.hpp:8
stan::math::multiply_lower_tri_self_transpose
Eigen::Matrix< fvar< T >, R, R > multiply_lower_tri_self_transpose(const Eigen::Matrix< fvar< T >, R, C > &m)
Definition: multiply_lower_tri_self_transpose.hpp:17
Eigen.hpp
stan::math::read_corr_L
Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > read_corr_L(const Eigen::Array< T, Eigen::Dynamic, 1 > &CPCs, const size_t K)
Return the Cholesky factor of the correlation matrix of the specified dimensionality corresponding to...
Definition: read_corr_L.hpp:41
read_corr_L.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.